@@ -1,5 +1,5 @@
 /*  Copyright 1986-1992 Emmet P. Gray.
- *  Copyright 1994,1996-2002,2007-2009 Alain Knaff.
+ *  Copyright 1994,1996-2002,2007-2009,2021-2022 Alain Knaff.
  *  This file is part of mtools.
  *
  *  Mtools is free software: you can redistribute it and/or modify
@@ -22,16 +22,16 @@
 
 
 #include "sysincludes.h"
-#include "msdos.h"
 #include "mtools.h"
-#include "vfat.h"
 #include "mainloop.h"
 #include "plain_io.h"
 #include "nameclash.h"
 #include "file.h"
 #include "fs.h"
 
-
+#if defined(HAVE_UTIMES) && defined(HAVE_SYS_TIME_H)
+#include <sys/time.h>
+#endif
 /*
  * Preserve the file modification times after the fclose()
  */
@@ -48,6 +48,12 @@ static void set_mtime(const char *target, time_t mtime)
 		utimes(target, tv);
 #else
 #ifdef HAVE_UTIME
+#ifndef HAVE_UTIMBUF
+		struct utimbuf {
+			time_t actime;       /* access time */
+			time_t modtime;      /* modification time */
+		};
+#endif		
 		struct utimbuf utbuf;
 
 		utbuf.actime = mtime;
@@ -107,7 +113,6 @@ static int _unix_write(MainParam_t *mp, int needfilter, const char *unixFile)
 	Stream_t *File=mp->File;
 	Stream_t *Target, *Source;
 	struct MT_STAT stbuf;
-	ssize_t ret;
 	char errmsg[80];
 
 	File->Class->get_data(File, &mtime, 0, 0, 0);
@@ -164,19 +169,18 @@ static int _unix_write(MainParam_t *mp, int needfilter, const char *unixFile)
 	if ((Target = SimpleFileOpen(0, 0, unixFile,
 				     O_WRONLY | O_CREAT | O_TRUNC,
 				     errmsg, 0, 0, 0))) {
-		ret = 0;
-		if(needfilter && arg->textmode){
-			Source = open_filter(COPY(File),arg->convertCharset);
-			if (!Source)
-				ret = -1;
-		} else
-			Source = COPY(File);
+		mt_off_t ret;
+		Source = COPY(File);
+		if(needfilter && arg->textmode)
+			Source = open_dos2unix(Source,arg->convertCharset);
 
-		if (ret == 0 )
+		if (Source)
 			ret = copyfile(Source, Target);
+		else
+			ret = -1;
 		FREE(&Source);
 		FREE(&Target);
-		if(ret <= -1){
+		if(ret < 0){
 			if(!arg->type)
 				unlink(unixFile);
 			return ERROR_ONE;
@@ -291,13 +295,12 @@ static int writeit(struct dos_name_t *dosname,
 	mt_off_t ret;
 	uint32_t fat;
 	time_t date;
-	mt_off_t filesize, newsize;
+	mt_off_t filesize;
 	Arg_t *arg = (Arg_t *) arg0;
+	Stream_t *Source = COPY(arg->mp.File);
 
-
-
-	if (arg->mp.File->Class->get_data(arg->mp.File,
-									  & date, &filesize, &type, 0) < 0 ){
+	if (Source->Class->get_data(Source, &date, &filesize,
+				    &type, 0) < 0 ){
 		fprintf(stderr, "Can't stat source file\n");
 		return -1;
 	}
@@ -336,22 +339,19 @@ static int writeit(struct dos_name_t *dosname,
 		fprintf(stderr,"Could not open Target\n");
 		exit(1);
 	}
-	if (arg->needfilter & arg->textmode)
-		Target = open_filter(Target,arg->convertCharset);
-
-
-
-	ret = copyfile(arg->mp.File, Target);
-	GET_DATA(Target, 0, &newsize, 0, &fat);
+	if (arg->needfilter & arg->textmode) {
+		Source = open_unix2dos(Source,arg->convertCharset);
+	}
+		
+	ret = copyfile(Source, Target);
+	GET_DATA(Target, 0, 0, 0, &fat);
+	FREE(&Source);
 	FREE(&Target);
-	if (arg->needfilter & arg->textmode)
-	    newsize++; /* ugly hack: we gathered the size before the Ctrl-Z
-			* was written.  Increment it manually */
 	if(ret < 0 ){
 		fat_free(arg->mp.targetDir, fat);
 		return -1;
 	} else {
-		mk_entry(dosname, arg->attr, fat, (uint32_t)newsize,
+		mk_entry(dosname, arg->attr, fat, (uint32_t)ret,
 				 now, &entry->dir);
 		return 0;
 	}
@@ -559,7 +559,7 @@ void mcopy(int argc, char **argv, int mtype)
 				batchmode = 1;
 				break;
 			case 'o':
-				handle_clash_options(&arg.ch, (char) c);
+				handle_clash_options(&arg.ch, c);
 				break;
 			case 'D':
 				if(handle_clash_options(&arg.ch, *optarg))
