@@ -18,10 +18,10 @@
 #include "sysincludes.h"
 #include "mtools.h"
 
-const char *mversion="4.0.40";
+const char *mversion="4.0.41";
 
 /* Multiple releases on same day should be marked with (b), (cd), (d) after
  * date string below */
-const char *mdate = "June 6th, 2022";
+const char *mdate = "September 18th, 2022";
 
-const char *mformat_banner = "MTOO4040";
+const char *mformat_banner = "MTOO4041";
